@@ -89,6 +89,33 @@ transfer_single_new_db(migratorContext *ctx, pageCnvCtx *pageConverter,
 					maps[mapnum].old_nspname, maps[mapnum].old_relname,
 					maps[mapnum].new_nspname, maps[mapnum].new_relname);
 
+		if (GET_MAJOR_VERSION(ctx->old.pg_version) >= 804 &&
+			GET_MAJOR_VERSION(ctx->new.pg_version) >= 804)
+		{
+			/*
+			 * Now copy/link any fsm and vm files, if they exist
+			 */
+			snprintf(scandir_file_pattern, sizeof(scandir_file_pattern), "%u_", maps[mapnum].old);
+			numFiles = pg_scandir(ctx, maps[mapnum].old_file, &namelist, dir_matching_filenames, NULL);
+	
+			while (numFiles--)
+			{
+				snprintf(old_file, sizeof(old_file), "%s/%s", maps[mapnum].old_file,
+						 namelist[numFiles]->d_name);
+				snprintf(new_file, sizeof(new_file), "%s/%u%s", maps[mapnum].new_file,
+						 maps[mapnum].new, strchr(namelist[numFiles]->d_name, '_'));
+	
+				unlink(new_file);
+				transfer_relfile(ctx, pageConverter, old_file, new_file,
+								 maps[mapnum].old_nspname, maps[mapnum].old_relname,
+								 maps[mapnum].new_nspname, maps[mapnum].new_relname);
+	
+				pg_free(namelist[numFiles]);
+			}
+	
+			pg_free(namelist);
+		}
+
 		/*
 		 * Now copy/link any related segments as well. Remember, PG breaks
 		 * large files into 1GB segments, the first segment has no extension,
