@@ -370,7 +370,7 @@ get_rel_infos(migratorContext *ctx, const char *db_name, RelInfoArr *relarr,
 				"			n.nspname "
 				"ORDER BY n.nspname, c.relname;",
 				FirstNormalObjectId,
-				/* see the comment at the top of v8_3_adjust_sequences() */
+				/* see the comment at the top of v8_3_create_sequence_script() */
 				(GET_MAJOR_VERSION(ctx->old.pg_version) <= 803 &&
 				 GET_MAJOR_VERSION(ctx->new.pg_version) >= 804) ?
 					"" : " OR relkind = 'S'",
@@ -593,8 +593,8 @@ check_loadable_libraries(migratorContext *ctx)
 				"| Your installation uses loadable libraries that are missing\n"
 				"| from the new installation.  You can add these libraries to\n"
 				"| the new installation, or remove the functions using them\n"
-				"| from the old installation.\n"
-				"| A list of the problem libraries is in the file\n"
+				"| from the old installation.  A list of the problem libraries\n"
+				"| is in the file\n"
 				"| \"%s\".\n\n", output_path);
 	}
 	else
@@ -648,7 +648,7 @@ relarr_lookup_rel(migratorContext *ctx, RelInfoArr *rel_arr,
 			return &rel_arr->rels[relnum];
 	}
 	pg_log(ctx, PG_FATAL, "Could not find %s.%s in %s cluster\n",
-		nspname, relname, whichCluster == CLUSTER_OLD ? "old" : "new");
+		nspname, relname, CLUSTERNAME(whichCluster));
 	return NULL;
 }
 
@@ -675,7 +675,7 @@ relarr_lookup_reloid(migratorContext *ctx, RelInfoArr *rel_arr, Oid oid,
 			return &rel_arr->rels[relnum];
 	}
 	pg_log(ctx, PG_FATAL, "Could not find %d in %s cluster\n",
-		oid, whichCluster == CLUSTER_OLD ? "old" : "new");
+		oid, CLUSTERNAME(whichCluster));
 	return NULL;
 }
 
@@ -728,8 +728,7 @@ dbarr_print(migratorContext *ctx, DbInfoArr *arr, Cluster whichCluster)
 {
 	int			dbnum;
 
-	pg_log(ctx, PG_DEBUG, "%s databases\n",
-		   whichCluster == CLUSTER_OLD ? "old" : "new");
+	pg_log(ctx, PG_DEBUG, "%s databases\n", CLUSTERNAME(whichCluster));
 
 	for (dbnum = 0; dbnum < arr->ndbs; dbnum++)
 	{
