@@ -52,12 +52,12 @@ main(int argc, char **argv)
 		if (ctx.old.port == ctx.new.port)
 			pg_log(&ctx, PG_FATAL, "When checking a live server, "
 					"the old and new port numbers must be different.\n");
-		pg_log(&ctx, PG_REPORT, "Performing consistency checks on old live server\n");
+		pg_log(&ctx, PG_REPORT, "PerForming Consistency Checks on Old Live Server\n");
 		pg_log(&ctx, PG_REPORT, "------------------------------------------------\n");
 	}
 	else
 	{
-		pg_log(&ctx, PG_REPORT, "Performing consistency checks\n");
+		pg_log(&ctx, PG_REPORT, "Performing Consistency Checks\n");
 		pg_log(&ctx, PG_REPORT, "-----------------------------\n");
 	}
 
@@ -94,6 +94,7 @@ main(int argc, char **argv)
 	}
 
 	v8_3_check_for_isn_and_int8_passing_mismatch(&ctx, CLUSTER_OLD);
+	
 	if (GET_MAJOR_VERSION(ctx.old.pg_version) <= 803 &&
 		GET_MAJOR_VERSION(ctx.new.pg_version) >= 804)
 	{
@@ -118,8 +119,12 @@ main(int argc, char **argv)
 		GET_MAJOR_VERSION(ctx.new.pg_version) >= 805)
 		v8_4_populate_pg_largeobject_metadata(&ctx, true, CLUSTER_OLD);
 
-	generate_old_dump(&ctx);
-	split_old_dump(&ctx);
+	/* While not a check option, we do this while the old server is running */
+	if (!ctx.check)
+	{
+		generate_old_dump(&ctx);
+		split_old_dump(&ctx);
+	}
 
 	if (!live_check)
 		stop_postmaster(&ctx, false, false);
@@ -134,8 +139,6 @@ main(int argc, char **argv)
 
 	check_loadable_libraries(&ctx);
 
-	stop_postmaster(&ctx, false, false);
-
 	check_locale_and_encoding(&ctx, &ctx.old.controldata, &ctx.new.controldata);
 
 	if (ctx.transfer_mode == TRANSFER_MODE_LINK)
@@ -144,20 +147,40 @@ main(int argc, char **argv)
 	if (ctx.check)
 	{
 		pg_log(&ctx, PG_REPORT, "\n*Clusters are compatible*\n");
+		/* stops new cluster */
+		stop_postmaster(&ctx, false, false);
 		exit_nicely(&ctx, false);
 	}
 
-	pg_log(&ctx, PG_REPORT, "*Checks complete*\n\n");
+	pg_log(&ctx, PG_REPORT, "\n"
+		"| If pg_migrator fails after this point, you must\n"
+		"| re-initdb the new cluster before continuing.\n"
+		"| You will also need to remove the \".old\" suffix\n"
+		"| from old $PGDATA/global/pg_control");
+	if (ctx.num_tablespaces)
+		pg_log(&ctx, PG_REPORT,
+			" and old\n| tablespace directory names");
+	pg_log(&ctx, PG_REPORT, ".\n");
 
-	pg_log(&ctx, PG_REPORT, "Preparing for migration\n");
-	pg_log(&ctx, PG_REPORT, "-----------------------\n");
+	pg_log(&ctx, PG_REPORT, "\nPerforming Migration\n");
+	pg_log(&ctx, PG_REPORT, "--------------------\n");
 	
 	/*
-	 *	Non-Destructive Changes
+	 *	Destructive Changes to Old Cluster (New cluster still running)
 	 */
 
-	/* -- NEW -- */
-	start_postmaster(&ctx, CLUSTER_NEW, false);
+	/* rename pg_control so old server cannot be accidentally started */
+	rename_old_pg_control(&ctx);
+	
+	/*
+	 *	Rename all tablespace paths to .old so we can copy them later.
+	 */
+	rename_tablespaces(&ctx);
+	check_ok(&ctx);
+
+	/*
+	 *	Non-Destructive Changes to New Cluster
+	 */
 
 	/*
 	 * It would make more sense to freeze after loading the schema, but that
@@ -183,35 +206,10 @@ main(int argc, char **argv)
 
 	stop_postmaster(&ctx, false, false);
 
-
-	pg_log(&ctx, PG_REPORT, "\n"
-		"| If pg_migrator fails after this point, you must\n"
-		"| re-initdb the new cluster before continuing.\n");
-
-	if (ctx.num_tablespaces)
-		pg_log(&ctx, PG_REPORT,
-			"| You will also need to remove the \".old\" suffix\n"
-			"| from old $PGDATA/global/pg_control and old\n"
-			"| tablespace directory names before continuing.\n");
-		
-
-	pg_log(&ctx, PG_REPORT, "\nPerforming migration\n");
-	pg_log(&ctx, PG_REPORT, "--------------------\n");
-
 	/*
-	 *	Destructive Changes
+	 *	Destructive Changes to New Cluster
 	 */
 
-	/* rename pg_control so old server cannot be accidentally started */
-	rename_old_pg_control(&ctx);
-	
-	/*
-	 *	Rename all tablespace paths to .old so we can copy them later.
-	 */
-	prep_status(&ctx, "Renaming tablespaces to *.old");
-	rename_tablespaces(&ctx);
-	check_ok(&ctx);
-
 	copy_clog_xlog_xid(&ctx);
 	/* New now using xid of old system */
 
@@ -253,7 +251,7 @@ main(int argc, char **argv)
 
 	install_support_functions(&ctx);
 
-	prep_status(&ctx, "Restoring database schema");
+	prep_status(&ctx, "Restoring database schema to new cluster");
 	exec_prog(&ctx, true,
 			  SYSTEMQUOTE "\"%s/%s\" --set ON_ERROR_STOP=on --port %d "
 			  "-f \"%s/%s\" --dbname template1 >> \"%s\"" SYSTEMQUOTE,
@@ -332,14 +330,21 @@ main(int argc, char **argv)
 		stop_postmaster(&ctx, false, true);
 	}
 	
-	pg_log(&ctx, PG_REPORT, "\n*Upgrade complete*\n");
+	pg_log(&ctx, PG_REPORT, "*Upgrade complete*\n");
 
-	pg_log(&ctx, PG_REPORT, "\n"
-	  		"| Optimizer statistics and free space information\n"
-			"| are not transferred by pg_migrator, so consider\n"
-			"| running:\n"
-			"| \tvacuumdb --all --analyze\n" 
-			"| on the newly-upgraded cluster.\n");
+	if (GET_MAJOR_VERSION(ctx.old.pg_version) >= 804 &&
+		GET_MAJOR_VERSION(ctx.new.pg_version) >= 804)
+		pg_log(&ctx, PG_REPORT, "\n"
+			   "| Optimizer statistics is not transferred by pg_migrator\n"
+			   "| so consider running ANALYZE on all databases in the\n"
+			   "| newly-upgraded cluster.\n");
+	else
+		pg_log(&ctx, PG_REPORT, "\n"
+		  		"| Optimizer statistics and free space information\n"
+				"| are not transferred by pg_migrator so consider\n"
+				"| running:\n"
+				"| \tvacuumdb --all --analyze\n" 
+				"| on the newly-upgraded cluster.\n");
 
 	cleanup(&ctx);
 
@@ -393,8 +398,6 @@ split_old_dump(migratorContext *ctx)
 	char	filename[MAX_STRING];
 	bool	suppressed_username = false;
 	
-	prep_status(ctx, "Splitting old dump file");
-
 	snprintf(filename, sizeof(filename), "%s/%s", ctx->home_dir, ALL_DUMP_FILE);
 	if ((all_dump =	fopen(filename, "r")) == NULL)
 		pg_log(ctx, PG_FATAL, "Cannot open dump file %s\n", filename);
@@ -437,8 +440,6 @@ split_old_dump(migratorContext *ctx)
 	fclose(all_dump);
 	fclose(globals_dump);
 	fclose(db_dump);
-
-	check_ok(ctx);
 }
 
 
