@@ -206,8 +206,6 @@ get_pg_database_relfilenode(migratorContext *ctx, Cluster whichCluster)
 	PGresult   *res;
 	int			i_relfile;
 
-	prep_status(ctx, "Getting pg_database relfilenode");
-
 	res = executeQueryOrDie(ctx, conn,
 							"SELECT c.relname, c.relfilenode "
 							"FROM 	pg_catalog.pg_class c, "
@@ -225,8 +223,6 @@ get_pg_database_relfilenode(migratorContext *ctx, Cluster whichCluster)
 
 	PQclear(res);
 	PQfinish(conn);
-
-	check_ok(ctx);
 }
 
 
@@ -298,6 +294,8 @@ rename_tablespaces(migratorContext *ctx)
 	char		old_path[MAXPGPATH];
 	char		new_path[MAXPGPATH];
 
+	prep_status(ctx, "Adding \".old\" suffix to tablespace directory names");
+
 	for (tblnum = 0; tblnum < ctx->num_tablespaces; tblnum++)
 	{
 		/* rename the old tablespace directory to *.old */
