@@ -8,6 +8,7 @@
 
 #define POSTMASTER_UPTIME 20
 
+#define STARTUP_WARNING_TRIES 2
 
 static pgpid_t get_postmaster_pid(migratorContext *ctx, const char *datadir);
 static bool test_server_conn(migratorContext *ctx, int timeout,
@@ -165,25 +166,20 @@ start_postmaster(migratorContext *ctx, Cluster whichCluster, bool quiet)
 	const char *bindir;
 	const char *datadir;
 	unsigned short port;
-	const char *clusterName;
 
 	if (whichCluster == CLUSTER_OLD)
 	{
 		bindir = ctx->old.bindir;
 		datadir = ctx->old.pgdata;
 		port = ctx->old.port;
-		clusterName = "old";
 	}
 	else
 	{
 		bindir = ctx->new.bindir;
 		datadir = ctx->new.pgdata;
 		port = ctx->new.port;
-		clusterName = "new";
 	}
 
-	if (!quiet)
-		prep_status(ctx, "Starting postmaster to service %s cluster", clusterName);
 	/* use -l for Win32 */
 	sprintf(cmd, SYSTEMQUOTE "\"%s/pg_ctl\" -l \"%s\" -D \"%s\" "
 				"-o \"-p %d -c autovacuum=off -c autovacuum_freeze_max_age=2000000000\" "
@@ -194,10 +190,8 @@ start_postmaster(migratorContext *ctx, Cluster whichCluster, bool quiet)
 	/* wait for the server to start properly */
 
 	if (test_server_conn(ctx, POSTMASTER_UPTIME, whichCluster) == false)
-		pg_log(ctx, PG_FATAL, " Unable to start postmaster with the command: %s\nPerhaps pg_hba.conf was not set to \"trust\".",
-			   cmd);
-	if (!quiet)
-		check_ok(ctx);
+		pg_log(ctx, PG_FATAL, " Unable to start %s postmaster with the command: %s\nPerhaps pg_hba.conf was not set to \"trust\".",
+			   CLUSTERNAME(whichCluster), cmd);
 
 	if ((ctx->postmasterPID = get_postmaster_pid(ctx, datadir)) == 0)
 		pg_log(ctx, PG_FATAL, " Unable to get postmaster pid\n");
@@ -214,32 +208,24 @@ stop_postmaster(migratorContext *ctx, bool fast, bool quiet)
 {
 	const char *bindir;
 	const char *datadir;
-	const char *clusterName;
 
 	if (ctx->running_cluster == CLUSTER_OLD)
 	{
 		bindir = ctx->old.bindir;
 		datadir = ctx->old.pgdata;
-		clusterName = "old";
 	}
 	else if (ctx->running_cluster == CLUSTER_NEW)
 	{
 		bindir = ctx->new.bindir;
 		datadir = ctx->new.pgdata;
-		clusterName = "new";
 	}
 	else
 		return;	/* no cluster running */
 
-	if (!quiet)
-		prep_status(ctx, "Stopping postmaster servicing %s cluster", clusterName);
-
 	/* use -l for Win32 */
 	exec_prog(ctx, fast ? false : true,
 				SYSTEMQUOTE "\"%s/pg_ctl\" -l \"%s\" -D \"%s\" %s stop >> \"%s\" 2>&1" SYSTEMQUOTE,
 				bindir, ctx->logfile, datadir, fast ? "-m fast" : "", ctx->logfile);
-	if (!quiet)
-		check_ok(ctx);
 
 	ctx->postmasterPID = 0;
 	ctx->running_cluster = NONE;
@@ -263,23 +249,33 @@ test_server_conn(migratorContext *ctx, int timeout, Cluster whichCluster)
 	int			tries;
 	unsigned short port = (whichCluster == CLUSTER_OLD) ?
 				ctx->old.port : ctx->new.port;
-
+	bool		ret = false;
+	
 	snprintf(con_opts, sizeof(con_opts),
 			 "dbname = 'template1' user = '%s' port = %d ", ctx->user, port);
 
 	for (tries = 0; tries < timeout; tries++)
 	{
-		sleep(2);
+		sleep(1);
 		if ((conn = PQconnectdb(con_opts)) != NULL &&
 			PQstatus(conn) == CONNECTION_OK)
 		{
 			PQfinish(conn);
-			return true;
+			ret = true;
+			break;
 		}
-		pg_log(ctx, PG_REPORT, ".");
+
+		if (tries == STARTUP_WARNING_TRIES)
+			prep_status(ctx, "Trying to start %s server ",
+						 CLUSTERNAME(whichCluster));
+		else if (tries > STARTUP_WARNING_TRIES)
+			pg_log(ctx, PG_REPORT, ".");
 	}
 
-	return false;
+	if (tries > STARTUP_WARNING_TRIES)
+		check_ok(ctx);
+
+	return ret;
 }
 
 
